@@ -46,20 +46,20 @@ static int verbose_packets=0;
 static size_t current_clients_number = 0;
 
 static int start_full_timer=0;
-static u32bits tot_messages=0;
-static u32bits tot_send_messages=0;
-static u64bits tot_send_bytes = 0;
-static u32bits tot_recv_messages=0;
-static u64bits tot_recv_bytes = 0;
-static u64bits tot_send_dropped = 0;
+static uint32_t tot_messages=0;
+static uint32_t tot_send_messages=0;
+static uint64_t tot_send_bytes = 0;
+static uint32_t tot_recv_messages=0;
+static uint64_t tot_recv_bytes = 0;
+static uint64_t tot_send_dropped = 0;
 
 struct event_base* client_event_base=NULL;
 
 static int client_write(app_ur_session *elem);
 static int client_shutdown(app_ur_session *elem);
 
-static u64bits current_time = 0;
-static u64bits current_mstime = 0;
+static uint64_t current_time = 0;
+static uint64_t current_mstime = 0;
 
 static char buffer_to_send[65536]="\0";
 
@@ -74,18 +74,18 @@ static app_ur_session** elems = NULL;
 
 int RTP_PACKET_INTERVAL = 20;
 
-static inline s64bits time_minus(u64bits t1, u64bits t2) {
-	return ( (s64bits)t1 - (s64bits)t2 );
+static inline int64_t time_minus(uint64_t t1, uint64_t t2) {
+	return ( (int64_t)t1 - (int64_t)t2 );
 }
 
-static u64bits total_loss = 0;
-static u64bits total_jitter = 0;
-static u64bits total_latency = 0;
+static uint64_t total_loss = 0;
+static uint64_t total_jitter = 0;
+static uint64_t total_latency = 0;
 
-static u64bits min_latency = 0xFFFFFFFF;
-static u64bits max_latency = 0;
-static u64bits min_jitter = 0xFFFFFFFF;
-static u64bits max_jitter = 0;
+static uint64_t min_latency = 0xFFFFFFFF;
+static uint64_t max_latency = 0;
+static uint64_t min_jitter = 0xFFFFFFFF;
+static uint64_t max_jitter = 0;
 
 
 static int show_statistics = 0;
@@ -93,7 +93,7 @@ static int show_statistics = 0;
 ///////////////////////////////////////////////////////////////////////////////
 
 static void __turn_getMSTime(void) {
-  static u64bits start_sec = 0;
+  static uint64_t start_sec = 0;
   struct timespec tp={0,0};
 #if defined(CLOCK_REALTIME)
   clock_gettime(CLOCK_REALTIME, &tp);
@@ -102,21 +102,21 @@ static void __turn_getMSTime(void) {
 #endif
   if(!start_sec)
     start_sec = tp.tv_sec;
-  if(current_time != (u64bits)((u64bits)(tp.tv_sec)-start_sec))
+  if(current_time != (uint64_t)((uint64_t)(tp.tv_sec)-start_sec))
     show_statistics = 1;
-  current_time = (u64bits)((u64bits)(tp.tv_sec)-start_sec);
-  current_mstime = (u64bits)((current_time * 1000) + (tp.tv_nsec/1000000));
+  current_time = (uint64_t)((uint64_t)(tp.tv_sec)-start_sec);
+  current_mstime = (uint64_t)((current_time * 1000) + (tp.tv_nsec/1000000));
 }
 
 ////////////////////////////////////////////////////////////////////
 
-static int refresh_channel(app_ur_session* elem, u16bits method, uint32_t lt);
+static int refresh_channel(app_ur_session* elem, uint16_t method, uint32_t lt);
 
 //////////////////////// SS ////////////////////////////////////////
 
 static app_ur_session* init_app_session(app_ur_session *ss) {
   if(ss) {
-    ns_bzero(ss,sizeof(app_ur_session));
+    bzero(ss,sizeof(app_ur_session));
     ss->pinfo.fd=-1;
   }
   return ss;
@@ -125,7 +125,7 @@ static app_ur_session* init_app_session(app_ur_session *ss) {
 static app_ur_session* create_new_ss(void)
 {
 	++current_clients_number;
-	return init_app_session((app_ur_session*) turn_malloc(sizeof(app_ur_session)));
+	return init_app_session((app_ur_session*) malloc(sizeof(app_ur_session)));
 }
 
 static void uc_delete_session_elem_data(app_ur_session* cdi) {
@@ -142,20 +142,20 @@ static void uc_delete_session_elem_data(app_ur_session* cdi) {
 	      SSL_shutdown(cdi->pinfo.tcp_conn[i]->tcp_data_ssl);
 	    }
 	    if(cdi->pinfo.tcp_conn[i]->tcp_data_ssl) {
-	      SSL_FREE(cdi->pinfo.tcp_conn[i]->tcp_data_ssl);
+	      SSL_free(cdi->pinfo.tcp_conn[i]->tcp_data_ssl);
 	    }
 	    if(cdi->pinfo.tcp_conn[i]->tcp_data_fd>=0) {
 	    	socket_closesocket(cdi->pinfo.tcp_conn[i]->tcp_data_fd);
 	      cdi->pinfo.tcp_conn[i]->tcp_data_fd=-1;
 	    }
-	    turn_free(cdi->pinfo.tcp_conn[i], 111);
+	    free(cdi->pinfo.tcp_conn[i]);
 	    cdi->pinfo.tcp_conn[i]=NULL;
 	  }
 	}
       }
       cdi->pinfo.tcp_conn_number=0;
       if(cdi->pinfo.tcp_conn) {
-    	  turn_free(cdi->pinfo.tcp_conn, 111);
+    	  free(cdi->pinfo.tcp_conn);
     	  cdi->pinfo.tcp_conn=NULL;
       }
     }
@@ -166,7 +166,7 @@ static void uc_delete_session_elem_data(app_ur_session* cdi) {
 	    }
     }
     if(cdi->pinfo.ssl) {
-	    SSL_FREE(cdi->pinfo.ssl);
+	    SSL_free(cdi->pinfo.ssl);
     }
     if(cdi->pinfo.fd>=0) {
     	socket_closesocket(cdi->pinfo.fd);
@@ -202,7 +202,7 @@ int send_buffer(app_ur_conn_info *clnet_info, stun_buffer* message, int data_con
 			while(np-->0) {
 				int pos = (int)((unsigned long)random()%(unsigned long)message->len);
 				int val = (int)((unsigned long)random()%256);
-				message->buf[pos]=(u08bits)val;
+				message->buf[pos]=(uint8_t)val;
 			}
 		}
 	}
@@ -361,7 +361,7 @@ int recv_buffer(app_ur_conn_info *clnet_info, stun_buffer* message, int sync, in
 	int rc = 0;
 
 	stun_tid tid;
-	u16bits method = 0;
+	uint16_t method = 0;
 
 	if(request_message) {
 		stun_tid_from_message(request_message, &tid);
@@ -620,7 +620,7 @@ int recv_buffer(app_ur_conn_info *clnet_info, stun_buffer* message, int sync, in
 		if(request_message) {
 
 			stun_tid recv_tid;
-			u16bits recv_method = 0;
+			uint16_t recv_method = 0;
 
 			stun_tid_from_message(message, &recv_tid);
 			recv_method = stun_get_method(message);
@@ -652,7 +652,7 @@ static int client_read(app_ur_session *elem, int is_tcp_data, app_tcp_conn_info
 
 	app_ur_conn_info *clnet_info = &(elem->pinfo);
 	int err_code = 0;
-	u08bits err_msg[129];
+	uint8_t err_msg[129];
 	int rc = 0;
 	int applen = 0;
 
@@ -678,8 +678,11 @@ static int client_read(app_ur_session *elem, int is_tcp_data, app_tcp_conn_info
 
 		if(is_tcp_data) {
 		  if ((int)elem->in_buffer.len == clmessage_length) {
-		    ns_bcopy((elem->in_buffer.buf), &mi, sizeof(message_info));
+		    bcopy((elem->in_buffer.buf), &mi, sizeof(message_info));
 		    miset=1;
+		  } else {
+			/* TODO: make a more clean fix */ 
+			buffers=(int)elem->in_buffer.len / clmessage_length;
 		  }
 		} else if (stun_is_indication(&(elem->in_buffer))) {
 
@@ -687,17 +690,17 @@ static int client_read(app_ur_session *elem, int is_tcp_data, app_tcp_conn_info
 
 			if((method == STUN_METHOD_CONNECTION_ATTEMPT)&& is_TCP_relay()) {
 			  stun_attr_ref sar = stun_attr_get_first(&(elem->in_buffer));
-			  u32bits cid = 0;
+			  uint32_t cid = 0;
 			  while(sar) {
 				  int attr_type = stun_attr_get_type(sar);
 				  if(attr_type == STUN_ATTRIBUTE_CONNECTION_ID) {
-					  cid = *((const u32bits*)stun_attr_get_value(sar));
+					  cid = *((const uint32_t*)stun_attr_get_value(sar));
 					  break;
 				  }
 				  sar = stun_attr_get_next_str(elem->in_buffer.buf,elem->in_buffer.len,sar);
 			  }
 			  if(negative_test) {
-				  tcp_data_connect(elem,(u64bits)random());
+				  tcp_data_connect(elem,(uint64_t)random());
 			  } else {
 				  /* positive test */
 				  tcp_data_connect(elem,cid);
@@ -725,9 +728,9 @@ static int client_read(app_ur_session *elem, int is_tcp_data, app_tcp_conn_info
 					return rc;
 				}
 
-				const u08bits* data = stun_attr_get_value(sar);
+				const uint8_t* data = stun_attr_get_value(sar);
 
-				ns_bcopy(data, &mi, sizeof(message_info));
+				bcopy(data, &mi, sizeof(message_info));
 				miset=1;
 			}
 
@@ -740,11 +743,11 @@ static int client_read(app_ur_session *elem, int is_tcp_data, app_tcp_conn_info
 
 			if(is_TCP_relay() && (stun_get_method(&(elem->in_buffer)) == STUN_METHOD_CONNECT)) {
 				stun_attr_ref sar = stun_attr_get_first(&(elem->in_buffer));
-				u32bits cid = 0;
+				uint32_t cid = 0;
 				while(sar) {
 				  int attr_type = stun_attr_get_type(sar);
 				  if(attr_type == STUN_ATTRIBUTE_CONNECTION_ID) {
-					  cid = *((const u32bits*)stun_attr_get_value(sar));
+					  cid = *((const uint32_t*)stun_attr_get_value(sar));
 					  break;
 				  }
 				  sar = stun_attr_get_next_str(elem->in_buffer.buf,elem->in_buffer.len,sar);
@@ -783,7 +786,7 @@ static int client_read(app_ur_session *elem, int is_tcp_data, app_tcp_conn_info
 					return rc;
 				}
 
-				ns_bcopy(elem->in_buffer.buf + 4, &mi, sizeof(message_info));
+				bcopy(elem->in_buffer.buf + 4, &mi, sizeof(message_info));
 				miset=1;
 				applen = elem->in_buffer.len -4;
 			}
@@ -801,14 +804,14 @@ static int client_read(app_ur_session *elem, int is_tcp_data, app_tcp_conn_info
 			if(mi.msgnum != elem->recvmsgnum+1)
 				++(elem->loss);
 			else {
-			  u64bits clatency = (u64bits)time_minus(current_mstime,mi.mstime);
+			  uint64_t clatency = (uint64_t)time_minus(current_mstime,mi.mstime);
 			  if(clatency>max_latency)
 			    max_latency = clatency;
 			  if(clatency<min_latency)
 			    min_latency = clatency;
 			  elem->latency += clatency;
 			  if(elem->rmsgnum>0) {
-			    u64bits cjitter = abs((int)(current_mstime-elem->recvtimems)-RTP_PACKET_INTERVAL);
+			    uint64_t cjitter = abs((int)(current_mstime-elem->recvtimems)-RTP_PACKET_INTERVAL);
 			    
 			    if(cjitter>max_jitter)
 			      max_jitter = cjitter;
@@ -1002,7 +1005,7 @@ static int start_client(const char *remote_address, int port,
     ss_rtcp = create_new_ss();
 
   app_ur_conn_info clnet_info_probe; /* for load balancing probe */
-  ns_bzero(&clnet_info_probe,sizeof(clnet_info_probe));
+  bzero(&clnet_info_probe,sizeof(clnet_info_probe));
   clnet_info_probe.fd = -1;
 
   app_ur_conn_info *clnet_info=&(ss->pinfo);
@@ -1022,7 +1025,7 @@ static int start_client(const char *remote_address, int port,
 		   clnet_info_rtcp, &chnum_rtcp);
 		   
   if(clnet_info_probe.ssl) {
-  	SSL_FREE(clnet_info_probe.ssl);
+  	SSL_free(clnet_info_probe.ssl);
   	clnet_info_probe.fd = -1;
   } else if(clnet_info_probe.fd != -1) {
 	  socket_closesocket(clnet_info_probe.fd);
@@ -1096,7 +1099,7 @@ static int start_c2c(const char *remote_address, int port,
     ss2_rtcp = create_new_ss();
 
   app_ur_conn_info clnet_info_probe; /* for load balancing probe */
-  ns_bzero(&clnet_info_probe,sizeof(clnet_info_probe));
+  bzero(&clnet_info_probe,sizeof(clnet_info_probe));
   clnet_info_probe.fd = -1;
 
   app_ur_conn_info *clnet_info1=&(ss1->pinfo);
@@ -1126,7 +1129,7 @@ static int start_c2c(const char *remote_address, int port,
 		       clnet_info2_rtcp, &chnum2_rtcp);
 		       
   if(clnet_info_probe.ssl) {
-	SSL_FREE(clnet_info_probe.ssl);
+	SSL_free(clnet_info_probe.ssl);
 	clnet_info_probe.fd = -1;
   } else if(clnet_info_probe.fd != -1) {
 	  socket_closesocket(clnet_info_probe.fd);
@@ -1219,7 +1222,7 @@ static int start_c2c(const char *remote_address, int port,
   return 0;
 }
 
-static int refresh_channel(app_ur_session* elem, u16bits method, uint32_t lt)
+static int refresh_channel(app_ur_session* elem, uint16_t method, uint32_t lt)
 {
 
 	stun_buffer message;
@@ -1234,10 +1237,10 @@ static int refresh_channel(app_ur_session* elem, u16bits method, uint32_t lt)
 		stun_attr_add(&message, STUN_ATTRIBUTE_LIFETIME, (const char*) &lt, 4);
 
 		if(dual_allocation && !mobility) {
-			int t = ((u08bits)random())%3;
+			int t = ((uint8_t)random())%3;
 			if(t) {
-				u08bits field[4];
-				field[0] = (t==1) ? (u08bits)STUN_ATTRIBUTE_REQUESTED_ADDRESS_FAMILY_VALUE_IPV4 : (u08bits)STUN_ATTRIBUTE_REQUESTED_ADDRESS_FAMILY_VALUE_IPV6;
+				uint8_t field[4];
+				field[0] = (t==1) ? (uint8_t)STUN_ATTRIBUTE_REQUESTED_ADDRESS_FAMILY_VALUE_IPV4 : (uint8_t)STUN_ATTRIBUTE_REQUESTED_ADDRESS_FAMILY_VALUE_IPV6;
 				field[1]=0;
 				field[2]=0;
 				field[3]=0;
@@ -1388,10 +1391,10 @@ void start_mclient(const char *remote_address, int port,
 	      ++mclient;
 	}
 
-	elems = (app_ur_session**)turn_malloc(sizeof(app_ur_session)*((mclient*2)+1)+sizeof(void*));
+	elems = (app_ur_session**)malloc(sizeof(app_ur_session)*((mclient*2)+1)+sizeof(void*));
 
 	__turn_getMSTime();
-	u32bits stime = current_time;
+	uint32_t stime = current_time;
 
 	memset(buffer_to_send, 7, clmessage_length);
 
@@ -1483,7 +1486,7 @@ void start_mclient(const char *remote_address, int port,
 	stime = current_time;
 
 	if(is_TCP_relay()) {
-		u64bits connect_wait_start_time = current_time;
+		uint64_t connect_wait_start_time = current_time;
 		while(1) {
 			int i = 0;
 			int completed = 0;
@@ -1525,7 +1528,7 @@ void start_mclient(const char *remote_address, int port,
 	stime = current_time;
 
 	for(i=0;i<total_clients;i++) {
-		elems[i]->to_send_timems = current_mstime + 1000 + ((u32bits)random())%5000;
+		elems[i]->to_send_timems = current_mstime + 1000 + ((uint32_t)random())%5000;
 	}
 
 	tot_messages = elems[0]->tot_msgnum * total_clients;
@@ -1586,7 +1589,7 @@ void start_mclient(const char *remote_address, int port,
 				(unsigned long)min_jitter,
 				(unsigned long)max_jitter);
 
-	turn_free(elems,0);
+	free(elems);
 }
 
 ///////////////////////////////////////////
@@ -1602,7 +1605,7 @@ int add_integrity(app_ur_conn_info *clnet_info, stun_buffer *message)
 
 		if(oauth && clnet_info->oauth) {
 
-			u16bits method = stun_get_method_str(message->buf, message->len);
+			uint16_t method = stun_get_method_str(message->buf, message->len);
 
 			int cok = clnet_info->cok;
 
@@ -1613,7 +1616,7 @@ int add_integrity(app_ur_conn_info *clnet_info, stun_buffer *message)
 				clnet_info->cok = cok;
 				oauth_token otoken;
 				encoded_oauth_token etoken;
-				u08bits nonce[12];
+				uint8_t nonce[12];
 				RAND_bytes((unsigned char*)nonce,12);
 				long halflifetime = OAUTH_SESSION_LIFETIME/2;
 				long random_lifetime = 0;
@@ -1639,13 +1642,13 @@ int add_integrity(app_ur_conn_info *clnet_info, stun_buffer *message)
 					return -1;
 				}
 				stun_attr_add_str(message->buf, (size_t*)&(message->len), STUN_ATTRIBUTE_OAUTH_ACCESS_TOKEN,
-					(const u08bits*)etoken.token, (int)etoken.size);
+					(const uint8_t*)etoken.token, (int)etoken.size);
 
-				ns_bcopy(otoken.enc_block.mac_key,clnet_info->key,otoken.enc_block.key_length);
+				bcopy(otoken.enc_block.mac_key,clnet_info->key,otoken.enc_block.key_length);
 				clnet_info->key_set = 1;
 			}
 
-			if(stun_attr_add_integrity_by_key_str(message->buf, (size_t*)&(message->len), (u08bits*)okey_array[cok].kid,
+			if(stun_attr_add_integrity_by_key_str(message->buf, (size_t*)&(message->len), (uint8_t*)okey_array[cok].kid,
 					clnet_info->realm, clnet_info->key, clnet_info->nonce, shatype)<0) {
 				TURN_LOG_FUNC(TURN_LOG_LEVEL_INFO," Cannot add integrity to the message\n");
 				return -1;
