@@ -36,11 +36,11 @@
 
 KHASH_MAP_INIT_INT64(3, ur_map_value_type)
 
-#define MAGIC_HASH ((u64bits)(0x90ABCDEFL))
+#define MAGIC_HASH ((uint64_t)(0x90ABCDEFL))
 
 struct _ur_map {
   khash_t(3) *h;
-  u64bits magic;
+  uint64_t magic;
   TURN_MUTEX_DECLARE(mutex)
 };
 
@@ -59,9 +59,9 @@ static int ur_map_init(ur_map* map) {
 #define ur_map_valid(map) ((map) && ((map)->h) && ((map)->magic==MAGIC_HASH))
 
 ur_map* ur_map_create() {
-  ur_map *map=(ur_map*)turn_malloc(sizeof(ur_map));
+  ur_map *map=(ur_map*)malloc(sizeof(ur_map));
   if(ur_map_init(map)<0) {
-    turn_free(map,sizeof(ur_map));
+    free(map);
     return NULL;
   }
   return map;
@@ -173,7 +173,7 @@ void ur_map_free(ur_map** map) {
     (*map)->h=NULL;
     (*map)->magic=0;
     TURN_MUTEX_DESTROY(&((*map)->mutex));
-    turn_free(*map,sizeof(ur_map));
+    free(*map);
     *map=NULL;
   }
 }
@@ -239,7 +239,7 @@ int ur_map_unlock(const ur_map* map) {
 void lm_map_init(lm_map *map)
 {
 	if(map) {
-		ns_bzero(map,sizeof(lm_map));
+		bzero(map,sizeof(lm_map));
 	}
 }
 
@@ -292,11 +292,11 @@ int lm_map_put(lm_map* map, ur_map_key_type key, ur_map_value_type value)
 					}
 				} else {
 					if(!(*keyp)) {
-						a->extra_keys[i] = (ur_map_key_type*)turn_malloc(sizeof(ur_map_key_type));
+						a->extra_keys[i] = (ur_map_key_type*)malloc(sizeof(ur_map_key_type));
 						keyp = a->extra_keys[i];
 					}
 					if(!(*valuep)) {
-						a->extra_values[i] = (ur_map_value_type*)turn_malloc(sizeof(ur_map_value_type));
+						a->extra_values[i] = (ur_map_value_type*)malloc(sizeof(ur_map_value_type));
 						valuep = a->extra_values[i];
 					}
 					*keyp = key;
@@ -308,13 +308,13 @@ int lm_map_put(lm_map* map, ur_map_key_type key, ur_map_value_type value)
 
 		size_t old_sz = esz;
 		size_t old_sz_mem = esz * sizeof(ur_map_key_type*);
-		a->extra_keys = (ur_map_key_type**)turn_realloc(a->extra_keys,old_sz_mem,old_sz_mem + sizeof(ur_map_key_type*));
-		a->extra_keys[old_sz] = (ur_map_key_type*)turn_malloc(sizeof(ur_map_key_type));
+		a->extra_keys = (ur_map_key_type**)realloc(a->extra_keys,old_sz_mem + sizeof(ur_map_key_type*));
+		a->extra_keys[old_sz] = (ur_map_key_type*)malloc(sizeof(ur_map_key_type));
 		*(a->extra_keys[old_sz]) = key;
 
 		old_sz_mem = esz * sizeof(ur_map_value_type*);
-		a->extra_values = (ur_map_value_type**)turn_realloc(a->extra_values,old_sz_mem,old_sz_mem + sizeof(ur_map_value_type*));
-		a->extra_values[old_sz] = (ur_map_value_type*)turn_malloc(sizeof(ur_map_value_type));
+		a->extra_values = (ur_map_value_type**)realloc(a->extra_values,old_sz_mem + sizeof(ur_map_value_type*));
+		a->extra_values[old_sz] = (ur_map_value_type*)malloc(sizeof(ur_map_value_type));
 		*(a->extra_values[old_sz]) = value;
 
 		a->extra_sz += 1;
@@ -444,10 +444,10 @@ void lm_map_clean(lm_map* map)
 					ur_map_key_type *keyp = a->extra_keys[i];
 					if(keyp) {
 						*keyp = 0;
-						turn_free(keyp,sizeof(ur_map_key_type));
+						free(keyp);
 					}
 				}
-				turn_free(a->extra_keys,esz * sizeof(ur_map_key_type));
+				free(a->extra_keys);
 				a->extra_keys = NULL;
 			}
 			if(a->extra_values) {
@@ -455,10 +455,10 @@ void lm_map_clean(lm_map* map)
 					ur_map_value_type *valuep = a->extra_values[i];
 					if(valuep) {
 						*valuep = 0;
-						turn_free(valuep,sizeof(ur_map_value_type));
+						free(valuep);
 					}
 				}
-				turn_free(a->extra_values,esz * sizeof(ur_map_value_type));
+				free(a->extra_values);
 				a->extra_values = NULL;
 			}
 		}
@@ -588,9 +588,9 @@ int lm_map_foreach_arg(lm_map* map, foreachcb_arg_type func, void* arg)
 static void addr_list_free(addr_list_header* slh) {
   if(slh) {
     if(slh->extra_list) {
-      turn_free(slh->extra_list,sizeof(addr_elem)*(slh->extra_sz));
+      free(slh->extra_list);
     }
-    ns_bzero(slh,sizeof(addr_list_header));
+    bzero(slh,sizeof(addr_list_header));
   }
 }
     
@@ -620,7 +620,7 @@ static void addr_list_add(addr_list_header* slh, const ioa_addr* key,  ur_addr_m
   if(!elem) {
 	  size_t old_sz = slh->extra_sz;
 	  size_t old_sz_mem = old_sz * sizeof(addr_elem);
-	  slh->extra_list = (addr_elem*)turn_realloc(slh->extra_list, old_sz_mem, old_sz_mem + sizeof(addr_elem));
+	  slh->extra_list = (addr_elem*)realloc(slh->extra_list, old_sz_mem + sizeof(addr_elem));
 	  elem = &(slh->extra_list[old_sz]);
 	  slh->extra_sz += 1;
   }
@@ -802,18 +802,18 @@ static const addr_elem* addr_list_get_const(const addr_list_header* slh, const i
 
 void ur_addr_map_init(ur_addr_map* map) {
   if(map) {
-    ns_bzero(map,sizeof(ur_addr_map));
+    bzero(map,sizeof(ur_addr_map));
     map->magic=MAGIC_HASH;
   }
 }
 
 void ur_addr_map_clean(ur_addr_map* map) {
   if(map && ur_addr_map_valid(map)) {
-    u32bits i=0;
+    uint32_t i=0;
     for(i=0;i<ADDR_MAP_SIZE;i++) {
       addr_list_free(&(map->lists[i]));
     }
-    ns_bzero(map,sizeof(ur_addr_map));
+    bzero(map,sizeof(ur_addr_map));
   }
 }
 
@@ -895,7 +895,7 @@ void ur_addr_map_foreach(ur_addr_map* map, ur_addr_map_func func) {
 
   if(ur_addr_map_valid(map)) {
 
-    u32bits i=0;
+    uint32_t i=0;
     for(i=0;i<ADDR_MAP_SIZE;i++) {
       
       addr_list_header* slh = &(map->lists[i]);
@@ -910,7 +910,7 @@ size_t ur_addr_map_num_elements(const ur_addr_map* map) {
 	size_t ret = 0;
 
 	if (ur_addr_map_valid(map)) {
-		u32bits i = 0;
+		uint32_t i = 0;
 		for (i = 0; i < ADDR_MAP_SIZE; i++) {
 
 			const addr_list_header* slh = &(map->lists[i]);
@@ -927,7 +927,7 @@ size_t ur_addr_map_size(const ur_addr_map* map) {
 	size_t ret = 0;
 
 	if (ur_addr_map_valid(map)) {
-		u32bits i = 0;
+		uint32_t i = 0;
 		for (i = 0; i < ADDR_MAP_SIZE; i++) {
 
 			const addr_list_header* slh = &(map->lists[i]);
@@ -948,7 +948,7 @@ typedef struct _string_list {
 typedef struct _string_elem {
   string_list list;
   ur_string_map_key_type key;
-  u32bits key_size;
+  uint32_t key_size;
   ur_string_map_value_type value;
 } string_elem;
 
@@ -967,10 +967,10 @@ static void string_list_free(string_list_header* slh, ur_string_map_func del_val
     while(list) {
       string_elem *elem=(string_elem*)list;
       string_list* tail=elem->list.next;
-      if(elem->key) turn_free(elem->key,elem->key_size);
+      if(elem->key) free(elem->key);
       if(del_value_func && elem->value)
 	      del_value_func(elem->value);
-      turn_free(elem,sizeof(string_elem));
+      free(elem);
       list=tail;
     }
     slh->list=NULL;
@@ -979,11 +979,11 @@ static void string_list_free(string_list_header* slh, ur_string_map_func del_val
 
 static string_list* string_list_add(string_list* sl, const ur_string_map_key_type key, ur_string_map_value_type value) {
   if(!key) return sl;
-  string_elem *elem=(string_elem*)turn_malloc(sizeof(string_elem));
+  string_elem *elem=(string_elem*)malloc(sizeof(string_elem));
   elem->list.next=sl;
   elem->key_size = strlen(key)+1;
-  elem->key=(s08bits*)turn_malloc(elem->key_size);
-  ns_bcopy(key,elem->key,elem->key_size);
+  elem->key=(char*)malloc(elem->key_size);
+  bcopy(key,elem->key,elem->key_size);
   elem->value=value;
   return &(elem->list);
 }
@@ -994,10 +994,10 @@ static string_list* string_list_remove(string_list* sl, const ur_string_map_key_
   string_elem *elem=(string_elem*)sl;
   string_list* tail=elem->list.next;
   if(strcmp(elem->key,key)==0) {
-    turn_free(elem->key,elem->key_size);
+    free(elem->key);
     if(del_value_func)
 	    del_value_func(elem->value);
-    turn_free(elem,sizeof(string_elem));
+    free(elem);
     if(counter) *counter+=1;
     sl=string_list_remove(tail, key, del_value_func, counter);
   } else {
@@ -1024,16 +1024,16 @@ static string_elem* string_list_get(string_list* sl, const ur_string_map_key_typ
 
 struct _ur_string_map {
   string_list_header lists[STRING_MAP_SIZE];
-  u64bits magic;
+  uint64_t magic;
   ur_string_map_func del_value_func;
   TURN_MUTEX_DECLARE(mutex)
 };
 
-static u32bits string_hash(const ur_string_map_key_type key) {
+static uint32_t string_hash(const ur_string_map_key_type key) {
 
-  u08bits *str=(u08bits*)key;
+  uint8_t *str=(uint8_t*)key;
 
-  u32bits hash = 0;
+  uint32_t hash = 0;
   int c = 0;
 
   while ((c = *str++))
@@ -1052,7 +1052,7 @@ static string_list_header* get_string_list_header(ur_string_map *map, const ur_s
 
 static int ur_string_map_init(ur_string_map* map) {
   if(map) {
-    ns_bzero(map,sizeof(ur_string_map));
+    bzero(map,sizeof(ur_string_map));
     map->magic=MAGIC_HASH;
 
     TURN_MUTEX_INIT_RECURSIVE(&(map->mutex));
@@ -1067,9 +1067,9 @@ static int ur_string_map_valid(const ur_string_map *map) {
 }
 
 ur_string_map* ur_string_map_create(ur_string_map_func del_value_func) {
-  ur_string_map *map=(ur_string_map*)turn_malloc(sizeof(ur_string_map));
+  ur_string_map *map=(ur_string_map*)malloc(sizeof(ur_string_map));
   if(ur_string_map_init(map)<0) {
-    turn_free(map,sizeof(ur_string_map));
+    free(map);
     return NULL;
   }
   map->del_value_func = del_value_func;
@@ -1166,7 +1166,7 @@ void ur_string_map_free(ur_string_map** map) {
     }
     (*map)->magic=0;
     TURN_MUTEX_DESTROY(&((*map)->mutex));
-    turn_free(*map,sizeof(ur_string_map));
+    free(*map);
     *map=NULL;
   }
 }
